# PACKAGE NAME
It's all about this package. In one line

## Installation
```pip3 install PACKAGE NAME```

## How to use it?
Open the terminal write PACKAGE NAME and woah

## License
© 2022 Yoshi Bansal

This repository is licensed under the MIT license.
See license for details.
